@@ -15,15 +15,18 @@ sudo apt-get install -y \
     libhtml-parser-perl \
     libjson-perl \
     liblist-moreutils-perl \
+    libmath-bigint-perl \
     libparse-yapp-perl \
+    libpython2.7-stdlib \
     libtext-unidecode-perl \
     libwww-curl-perl \
     libxml-simple-perl \
     openbabel \
     perl \
-    python-argparse \
-    libmath-bigint-gmp-perl \
 ;
 
-# The 'libmath-bigint-gmp-perl' package greatly improves the speed of
-# BigRat arithmetics.
+# The 'libmath-bigint-gmp-perl' package is not mandatory,
+# but it greatly improves the speed of BigRat arithmetics.
+sudo apt-get install -y \
+    libmath-bigint-gmp-perl \
+;
