@@ -2,8 +2,8 @@
 
 #BEGIN DEPEND------------------------------------------------------------------
 
-INPUT_SCRIPT=scripts/cif_printout_Python
-INPUT_CIF=tests/inputs/1000000.cif
+INPUT_SCRIPT=tests/scripts/cif_printout_Python
+INPUT_CIF=tests/inputs/cif_printout_Python/cif1/1000000.cif
 
 #END DEPEND--------------------------------------------------------------------
 
